#version 100
precision highp float;
precision highp int;

//#define M_PI 3.141592
#define M_PI 3.1415926535897932384626433832795

varying vec4 v_color;
varying vec2 v_texCoords0;
varying vec2 v_texCoords1;

uniform sampler2D u_texture;
uniform vec2 uv_repeat;
uniform float border_on_screen;
uniform float time;

vec4 back_color = vec4(0.098, 0.161, 0.082, 1);
vec4 front_color = vec4(1,1,1,1);
float border_size = 0.00014;
float move_amplitude = 0.1;
float scale_speed = 2.0;
vec2 disc_center = vec2(0.5, 0.5);
float disc_radius = 0.5 ;
float waveFrequency = 30.0;
float waveStrength = 1.0;
float speed = -0.361;

float rand(vec2 co)
{
    return fract(sin(dot(co.xy ,vec2(12.9898,78.233))) * 43758.5453);
}
float oscillate(float vMin, float vMax, float t) {
    float halfRange = (vMax - vMin) / vMax * 0.5;
    return (sin(t) * halfRange + (1.0 - halfRange)) * vMax;
}

vec3 hsv2rgb(vec3 c) {
  // Íñigo Quílez
  // https://www.shadertoy.com/view/MsS3Wc
  vec3 rgb = clamp(abs(mod(c.x*6.+vec3(0.,4.,2.),6.)-3.)-1.,0.,1.);
  rgb = rgb * rgb * (3. - 2. * rgb);
  return c.z * mix(vec3(1.), rgb, c.y);
}
void main() {
    vec4 bordercol = vec4(0,0,0,0);
    vec2 diskpos = v_texCoords1 - disc_center;
    float radius = length(diskpos);
    float wavespeed = waveFrequency * radius - time * speed;
    vec4 loopedcolor = vec4(hsv2rgb(vec3(0.5+time* 0.013, 1.0, 1.0)), 1.);

    // рисую границу края карты
    float tdisk = smoothstep(disc_radius + border_size, disc_radius - border_size, radius);
    float tcircle = 1.0 + smoothstep(disc_radius, disc_radius + border_size, radius) - smoothstep(disc_radius - border_size, disc_radius, radius);
    vec4 circle_color = vec4(oscillate(0.1,0.8, wavespeed * 2.0 ),oscillate(0.5,0.9,wavespeed * 2.0),0.8,1);
    bordercol = mix(loopedcolor, vec4(0.0,0.0,0.0,0.0), tcircle);


    if(radius > 0.5000) // рисую звезды за краями круга
    {
        float size = 30.0;
        float prob = 0.95;
        vec2 pos = floor(1.0 / size * gl_FragCoord.xy);

        float color = 0.0;
        float starValue = rand(pos);
        if (rand(gl_FragCoord.xy / vec2(1280.0,720.0)) > 0.996)
        {
               float r = rand(gl_FragCoord.xy);
               color = r * (0.25 * sin(time * (r * 5.0) + 720.0 * r) + 0.75);
        }

        vec4 stars = vec4(vec3(color*0.8,color*1.0, color*1.6 ), 1.0);
        gl_FragColor = vec4(0,0,0,1) + stars;
    }
    else //бэкграунд с волнами от краев
    {
        float addend = sin( wavespeed ) * waveStrength;
        addend = abs(addend);
        float p = pow(addend, 14.0);
        addend = clamp(p, 0.0, 1.0);
        //float diskmask = smoothstep(disc_radius + border_size, disc_radius - border_size, radius);
        float diskmask2 = smoothstep(disc_radius - 0.5, disc_radius + 0.5, radius * 1.5) ;

        vec4 t1 = texture2D(u_texture, v_texCoords0);

        vec4 radial_gradient = mix(vec4(t1.rgb, 1.0), vec4(t1.r * 0.3, t1.g * 0.34, t1.b * 0.7 + 0.1, 1.0), diskmask2);
        vec4 radial_gradient2 = loopedcolor * (clamp(diskmask2,0.043,0.15)) * (addend  * t1.a) + ((t1.a * loopedcolor) * 0.066);
        //vec4 res = mix(vec4(1,0,0,1), vec4(t1), diskmask);
        gl_FragColor = clamp(radial_gradient + radial_gradient2 + bordercol, vec4(0,0,0,0), vec4(1.0,1.0,1.0, 1.0)) ;
    }
}

